@@ -8,10 +8,10 @@ import (
 	"testing"
 
 	"github.com/MakeNowJust/heredoc"
+	"github.com/cli/cli/v2/internal/prompter"
 	"github.com/cli/cli/v2/internal/run"
 	"github.com/cli/cli/v2/pkg/httpmock"
 	"github.com/cli/cli/v2/pkg/iostreams"
-	"github.com/cli/cli/v2/pkg/prompt"
 	"github.com/cli/cli/v2/pkg/ssh"
 	"github.com/stretchr/testify/assert"
 )
@@ -47,14 +47,28 @@ func TestLogin_ssh(t *testing.T) {
 		httpmock.REST("POST", "api/v3/user/keys"),
 		httpmock.StringResponse(`{}`))
 
-	ask := prompt.NewAskStubber(t)
-
-	ask.StubPrompt("What is your preferred protocol for Git operations?").AnswerWith("SSH")
-	ask.StubPrompt("Generate a new SSH key to add to your GitHub account?").AnswerWith(true)
-	ask.StubPrompt("Enter a passphrase for your new SSH key (Optional)").AnswerWith("monkey")
-	ask.StubPrompt("Title for your SSH key:").AnswerWith("Test Key")
-	ask.StubPrompt("How would you like to authenticate GitHub CLI?").AnswerWith("Paste an authentication token")
-	ask.StubPrompt("Paste your authentication token:").AnswerWith("ATOKEN")
+	pm := &prompter.PrompterMock{}
+	pm.SelectFunc = func(prompt, _ string, opts []string) (int, error) {
+		switch prompt {
+		case "What is your preferred protocol for Git operations?":
+			return prompter.IndexFor(opts, "SSH")
+		case "How would you like to authenticate GitHub CLI?":
+			return prompter.IndexFor(opts, "Paste an authentication token")
+		}
+		return -1, prompter.NoSuchPromptErr(prompt)
+	}
+	pm.PasswordFunc = func(_ string) (string, error) {
+		return "monkey", nil
+	}
+	pm.ConfirmFunc = func(prompt string, _ bool) (bool, error) {
+		return true, nil
+	}
+	pm.AuthTokenFunc = func() (string, error) {
+		return "ATOKEN", nil
+	}
+	pm.InputFunc = func(_, _ string) (string, error) {
+		return "Test Key", nil
+	}
 
 	rs, runRestore := run.Stub()
 	defer runRestore(t)
@@ -77,6 +91,7 @@ func TestLogin_ssh(t *testing.T) {
 	err := Login(&LoginOptions{
 		IO:          ios,
 		Config:      &cfg,
+		Prompter:    pm,
 		HTTPClient:  &http.Client{Transport: &tr},
 		Hostname:    "example.com",
 		Interactive: true,
