@@ -21,7 +21,6 @@ func TestPendingOperationDisallowsLogs(t *testing.T) {
 }
 
 func testingLogsApp() *App {
-	user := &api.User{Login: "monalisa"}
 	disabledCodespace := &api.Codespace{
 		Name:                           "disabledCodespace",
 		PendingOperation:               true,
@@ -34,12 +33,6 @@ func testingLogsApp() *App {
 			}
 			return nil, nil
 		},
-		GetUserFunc: func(_ context.Context) (*api.User, error) {
-			return user, nil
-		},
-		AuthorizedKeysFunc: func(_ context.Context, _ string) ([]byte, error) {
-			return []byte{}, nil
-		},
 	}
 
 	ios, _, _, _ := iostreams.Test()
