@@ -6,12 +6,9 @@ import (
 
 	"github.com/AlecAivazis/survey/v2"
 	"github.com/cli/cli/v2/api"
-	"github.com/cli/cli/v2/git"
 	"github.com/cli/cli/v2/internal/ghrepo"
-	"github.com/cli/cli/v2/pkg/githubtemplate"
 	"github.com/cli/cli/v2/pkg/iostreams"
 	"github.com/cli/cli/v2/pkg/prompt"
-	"github.com/cli/cli/v2/pkg/surveyext"
 )
 
 type Action int
@@ -34,15 +31,22 @@ const (
 	cancelLabel      = "Cancel"
 )
 
-func ConfirmIssueSubmission(allowPreview bool, allowMetadata bool) (Action, error) {
-	return confirmSubmission(allowPreview, allowMetadata, false, false)
+type Prompt interface {
+	Input(string, string) (string, error)
+	Select(string, string, []string) (int, error)
+	MarkdownEditor(string, string, bool) (string, error)
+	Confirm(string, bool) (bool, error)
 }
 
-func ConfirmPRSubmission(allowPreview, allowMetadata, isDraft bool) (Action, error) {
-	return confirmSubmission(allowPreview, allowMetadata, true, isDraft)
+func ConfirmIssueSubmission(p Prompt, allowPreview bool, allowMetadata bool) (Action, error) {
+	return confirmSubmission(p, allowPreview, allowMetadata, false, false)
 }
 
-func confirmSubmission(allowPreview, allowMetadata, allowDraft, isDraft bool) (Action, error) {
+func ConfirmPRSubmission(p Prompt, allowPreview, allowMetadata, isDraft bool) (Action, error) {
+	return confirmSubmission(p, allowPreview, allowMetadata, true, isDraft)
+}
+
+func confirmSubmission(p Prompt, allowPreview, allowMetadata, allowDraft, isDraft bool) (Action, error) {
 	var options []string
 	if !isDraft {
 		options = append(options, submitLabel)
@@ -58,25 +62,12 @@ func confirmSubmission(allowPreview, allowMetadata, allowDraft, isDraft bool) (A
 	}
 	options = append(options, cancelLabel)
 
-	confirmAnswers := struct {
-		Confirmation int
-	}{}
-	confirmQs := []*survey.Question{
-		{
-			Name: "confirmation",
-			Prompt: &survey.Select{
-				Message: "What's next?",
-				Options: options,
-			},
-		},
-	}
-
-	err := prompt.SurveyAsk(confirmQs, &confirmAnswers)
+	result, err := p.Select("What's next?", "", options)
 	if err != nil {
 		return -1, fmt.Errorf("could not prompt: %w", err)
 	}
 
-	switch options[confirmAnswers.Confirmation] {
+	switch options[result] {
 	case submitLabel:
 		return SubmitAction, nil
 	case submitDraftLabel:
@@ -88,11 +79,11 @@ func confirmSubmission(allowPreview, allowMetadata, allowDraft, isDraft bool) (A
 	case cancelLabel:
 		return CancelAction, nil
 	default:
-		return -1, fmt.Errorf("invalid index: %d", confirmAnswers.Confirmation)
+		return -1, fmt.Errorf("invalid index: %d", result)
 	}
 }
 
-func BodySurvey(state *IssueMetadataState, templateContent, editorCommand string) error {
+func BodySurvey(p Prompt, state *IssueMetadataState, templateContent string) error {
 	if templateContent != "" {
 		if state.Body != "" {
 			// prevent excessive newlines between default body and template
@@ -102,61 +93,32 @@ func BodySurvey(state *IssueMetadataState, templateContent, editorCommand string
 		state.Body += templateContent
 	}
 
-	preBody := state.Body
-
-	// TODO should just be an AskOne but ran into problems with the stubber
-	qs := []*survey.Question{
-		{
-			Name: "Body",
-			Prompt: &surveyext.GhEditor{
-				BlankAllowed:  true,
-				EditorCommand: editorCommand,
-				Editor: &survey.Editor{
-					Message:       "Body",
-					FileName:      "*.md",
-					Default:       state.Body,
-					HideDefault:   true,
-					AppendDefault: true,
-				},
-			},
-		},
-	}
-
-	err := prompt.SurveyAsk(qs, state)
+	result, err := p.MarkdownEditor("Body", state.Body, true)
 	if err != nil {
 		return err
 	}
 
-	if preBody != state.Body {
+	if state.Body != result {
 		state.MarkDirty()
 	}
 
+	state.Body = result
+
 	return nil
 }
 
-func TitleSurvey(state *IssueMetadataState) error {
-	preTitle := state.Title
-
-	// TODO should just be an AskOne but ran into problems with the stubber
-	qs := []*survey.Question{
-		{
-			Name: "Title",
-			Prompt: &survey.Input{
-				Message: "Title",
-				Default: state.Title,
-			},
-		},
-	}
-
-	err := prompt.SurveyAsk(qs, state)
+func TitleSurvey(p Prompt, state *IssueMetadataState) error {
+	result, err := p.Input("Title", state.Title)
 	if err != nil {
 		return err
 	}
 
-	if preTitle != state.Title {
+	if result != state.Title {
 		state.MarkDirty()
 	}
 
+	state.Title = result
+
 	return nil
 }
 
@@ -197,6 +159,7 @@ func MetadataSurvey(io *iostreams.IOStreams, baseRepo ghrepo.Interface, fetcher
 	}
 	extraFieldsOptions = append(extraFieldsOptions, "Assignees", "Labels", "Projects", "Milestone")
 
+	//nolint:staticcheck // SA1019: prompt.SurveyAsk is deprecated: use Prompter
 	err := prompt.SurveyAsk([]*survey.Question{
 		{
 			Name: "metadata",
@@ -222,21 +185,29 @@ func MetadataSurvey(io *iostreams.IOStreams, baseRepo ghrepo.Interface, fetcher
 		return fmt.Errorf("error fetching metadata options: %w", err)
 	}
 
-	var users []string
+	var reviewers []string
 	for _, u := range metadataResult.AssignableUsers {
-		users = append(users, u.DisplayName())
+		if u.Login != metadataResult.CurrentLogin {
+			reviewers = append(reviewers, u.DisplayName())
+		}
 	}
-	var teams []string
 	for _, t := range metadataResult.Teams {
-		teams = append(teams, fmt.Sprintf("%s/%s", baseRepo.RepoOwner(), t.Slug))
+		reviewers = append(reviewers, fmt.Sprintf("%s/%s", baseRepo.RepoOwner(), t.Slug))
+	}
+	var assignees []string
+	for _, u := range metadataResult.AssignableUsers {
+		assignees = append(assignees, u.DisplayName())
 	}
 	var labels []string
 	for _, l := range metadataResult.Labels {
 		labels = append(labels, l.Name)
 	}
 	var projects []string
-	for _, l := range metadataResult.Projects {
-		projects = append(projects, l.Name)
+	for _, p := range metadataResult.Projects {
+		projects = append(projects, p.Name)
+	}
+	for _, p := range metadataResult.ProjectsV2 {
+		projects = append(projects, p.Title)
 	}
 	milestones := []string{noMilestone}
 	for _, m := range metadataResult.Milestones {
@@ -245,12 +216,12 @@ func MetadataSurvey(io *iostreams.IOStreams, baseRepo ghrepo.Interface, fetcher
 
 	var mqs []*survey.Question
 	if isChosen("Reviewers") {
-		if len(users) > 0 || len(teams) > 0 {
+		if len(reviewers) > 0 {
 			mqs = append(mqs, &survey.Question{
 				Name: "reviewers",
 				Prompt: &survey.MultiSelect{
 					Message: "Reviewers",
-					Options: append(users, teams...),
+					Options: reviewers,
 					Default: state.Reviewers,
 				},
 			})
@@ -259,12 +230,12 @@ func MetadataSurvey(io *iostreams.IOStreams, baseRepo ghrepo.Interface, fetcher
 		}
 	}
 	if isChosen("Assignees") {
-		if len(users) > 0 {
+		if len(assignees) > 0 {
 			mqs = append(mqs, &survey.Question{
 				Name: "assignees",
 				Prompt: &survey.MultiSelect{
 					Message: "Assignees",
-					Options: users,
+					Options: assignees,
 					Default: state.Assignees,
 				},
 			})
@@ -327,6 +298,7 @@ func MetadataSurvey(io *iostreams.IOStreams, baseRepo ghrepo.Interface, fetcher
 		Milestone string
 	}{}
 
+	//nolint:staticcheck // SA1019: prompt.SurveyAsk is deprecated: use Prompter
 	err = prompt.SurveyAsk(mqs, &values)
 	if err != nil {
 		return fmt.Errorf("could not prompt: %w", err)
@@ -364,18 +336,3 @@ func MetadataSurvey(io *iostreams.IOStreams, baseRepo ghrepo.Interface, fetcher
 
 	return nil
 }
-
-func FindTemplates(dir, path string) ([]string, string) {
-	if dir == "" {
-		rootDir, err := git.ToplevelDir()
-		if err != nil {
-			return []string{}, ""
-		}
-		dir = rootDir
-	}
-
-	templateFiles := githubtemplate.FindNonLegacy(dir, path)
-	legacyTemplate := githubtemplate.FindLegacy(dir, path)
-
-	return templateFiles, legacyTemplate
-}
