@@ -48,10 +48,7 @@ func Test_executable(t *testing.T) {
 	}
 
 	oldPath := os.Getenv("PATH")
-	t.Cleanup(func() {
-		os.Setenv("PATH", oldPath)
-	})
-	os.Setenv("PATH", strings.Join([]string{bin1, bin2, bin3, oldPath}, string(os.PathListSeparator)))
+	t.Setenv("PATH", strings.Join([]string{bin1, bin2, bin3, oldPath}, string(os.PathListSeparator)))
 
 	if got := executable(""); got != bin2Exe {
 		t.Errorf("executable() = %q, want %q", got, bin2Exe)
